@@ -37,7 +37,7 @@
 // Utility 'zip' function analogous to python's, from
 // https://stackoverflow.com/questions/4856717
 
-const Chart = require('chart.js');
+require('chart.js');
 const { nodeName } = require('jquery');
 var tinycolor = require('tinycolor2');
 require('chartjs-plugin-zoom');
@@ -119,7 +119,7 @@ function getValidPointNames(allData) {
 
 
 /////////////// MAIN CLASS DEFINITION /////////////////
-var BandPlot = function (divID, showFermi, showLegend, yLimit) {
+var BandPlot = function (divID, showFermi, showLegend, yLimit, dosRange) {
     this.divID = divID;
     this.allData = [];
     this.dosData = {};
@@ -135,6 +135,7 @@ var BandPlot = function (divID, showFermi, showLegend, yLimit) {
     this.showFermi = showFermi;
     this.showLegend = showLegend;
     this.yLimit = yLimit;
+    this.dosRange = dosRange;
     this.yLabel = "";
 
     if (typeof (this.myChart) != "undefined") {
@@ -176,7 +177,7 @@ BandPlot.prototype.addBandStructure = function (bandsData, colorInfo) {
 BandPlot.prototype.addDos = function (dosData) {
     this.dosData = dosData;
 
-    var Index = 1 + dosData['pdos'].length;
+    var Index = dosData['dos'].length;
     var defaultColors = ['#555555', '#e41a1c', '#377eb8', '#4daf4a', '#984ea3', '#ff7f00', '#ffff33', '#a65628', '#f781bf', '#999999'];
 
     for (let i = 0; i < Index; i++) {
@@ -233,7 +234,7 @@ BandPlot.prototype.initChart = function (ticksData) {
                     customTicks: ticksData,
                     afterBuildTicks: function (axis, ticks) {
                         // Must return 'filtered' ticks, i.e. a list of
-                        // *positions* of the ticks only. 
+                        // *positions* of the ticks only.
                         // Here I instead just discart the old ticks
                         // and create new ones. The label
                         // will be changed in the ticks.callback call.
@@ -286,7 +287,6 @@ BandPlot.prototype.initChart = function (ticksData) {
     if (bandPlotObject.yLabel)
         chartOptions.options.scales.yAxes[0].scaleLabel.labelString = bandPlotObject.yLabel;
 
-    console.log("The bandstructure Div ID is:" + this.divID);
     var ctx = document.getElementById(this.divID).getContext('2d');
     bandPlotObject.myChart = new Chart(ctx, chartOptions);
 };
@@ -342,7 +342,8 @@ BandPlot.prototype.initDosChart = function (orientation = 'vertical') {
                             zeroLineWidth: 2,
                         },
                         ticks: {
-                            // min: 0.0,
+                            min: bandPlotObject.dosRange[0],
+                            max: bandPlotObject.dosRange[1],
                         }
                     }],
                     yAxes: [{
@@ -453,7 +454,8 @@ BandPlot.prototype.initDosChart = function (orientation = 'vertical') {
                             tickMarkLength: 0,
                         },
                         ticks: {
-                            // min: 0.0,
+                            min: bandPlotObject.dosRange[0],
+                            max: bandPlotObject.dosRange[1],
                             padding: 10,
                         },
                         scaleLabel: {
@@ -716,6 +718,8 @@ BandPlot.prototype.updateBandPlot = function (bandPath, forceRedraw) {
                             pointRadius: 0
                         };
 
+                        if (twoBandTypes && band_idx * 2 >= numBands) series.borderDash = [10, 5];
+
                         bandPlotObject.allSeries.push(series);
                     });
                 } else {
@@ -779,61 +783,36 @@ BandPlot.prototype.updateDosPlot = function (orientation = 'vertical') {
     // Plot the density of states
     bandPlotObject.dosSeries = [];
     curve = [];
-    var totx = bandPlotObject.dosData['tdos']['x'];
-    var toty = bandPlotObject.dosData['tdos']['y'];
 
-    totx.forEach(function (data, i) {
-        if (orientation === 'vertical') {
-            curve.push({ x: toty[i], y: data - bandPlotObject.dosFermiEnergy });
-        } else {
-            curve.push({ x: data - bandPlotObject.dosFermiEnergy, y: toty[i] });
-        };
-    });
-
-    var totdos = {
-        borderColor: bandPlotObject.dosData['tdos']['borderColor'],
-        backgroundColor: bandPlotObject.dosData['tdos']['backgroundColor'],
-        borderWidth: 2,
-        data: curve,
-        fill: true,
-        showLine: true,
-        pointRadius: 0,
-        label: "Total",
-    };
-
-    if (bandPlotObject.dosData['tdos']['lineStyle'] == 'dash') totdos.borderDash =[10, 5]; 
-
-    bandPlotObject.dosSeries.push(totdos);
-
-    for (let i = 0; i < bandPlotObject.dosData['pdos'].length; i++) {
+    for (let i = 0; i < bandPlotObject.dosData['dos'].length; i++) {
         curve = [];
 
-        var pdosx = bandPlotObject.dosData['pdos'][i]['x'];
-        var pdosy = bandPlotObject.dosData['pdos'][i]['y'];
+        var dosx = bandPlotObject.dosData['dos'][i]['x'];
+        var dosy = bandPlotObject.dosData['dos'][i]['y'];
 
-        pdosx.forEach(function (data, k) {
+        dosx.forEach(function (data, k) {
             if (orientation === 'vertical') {
-                curve.push({ x: pdosy[k], y: data - bandPlotObject.dosFermiEnergy });
+                curve.push({ x: dosy[k], y: data - bandPlotObject.dosFermiEnergy });
             } else {
-                curve.push({ x: data - bandPlotObject.dosFermiEnergy, y: pdosy[k] });
+                curve.push({ x: data - bandPlotObject.dosFermiEnergy, y: dosy[k] });
             };
         });
 
-        var pdos = {
-            borderColor: bandPlotObject.dosData['pdos'][i]['borderColor'],
-            backgroundColor: bandPlotObject.dosData['pdos'][i]['backgroundColor'],
+        var dos = {
+            borderColor: bandPlotObject.dosData['dos'][i]['borderColor'],
+            backgroundColor: bandPlotObject.dosData['dos'][i]['backgroundColor'],
             hidden: false,
             borderWidth: 1,
             data: curve,
             fill: true,
             showLine: true,
             pointRadius: 0,
-            label: bandPlotObject.dosData['pdos'][i]['label'],
+            label: bandPlotObject.dosData['dos'][i]['label'],
         };
 
-        if (bandPlotObject.dosData['pdos'][i]['lineStyle'] === 'dash') pdos.borderDash = [10, 5];
+        if (bandPlotObject.dosData['dos'][i]['lineStyle'] === 'dash') dos.borderDash = [10, 5];
 
-        bandPlotObject.dosSeries.push(pdos);
+        bandPlotObject.dosSeries.push(dos);
     };
 
     if (bandPlotObject.myDos === undefined) {
@@ -852,7 +831,7 @@ BandPlot.prototype.resBandZoom = function () {
     // Sometimes these are wrongly set (e.g. if I:
     // 1. zoom
     // 2. change the path to something shorter than the default
-    // 3. reset the Zoom). 
+    // 3. reset the Zoom).
     // So, we reset them according to the current path
     bandPlotObject.myChart.options.scales.xAxes[0].ticks.min = bandPlotObject.xLimit.xmin;
     bandPlotObject.myChart.options.scales.xAxes[0].ticks.max = bandPlotObject.xLimit.xmax;
@@ -1033,4 +1012,4 @@ module.exports = {
     getPathStringFromPathArray: getPathStringFromPathArray,
     getValidPointNames: getValidPointNames,
     getPathArrayFromPathString: getPathArrayFromPathString,
-}
\ No newline at end of file
+}
