@@ -1,5 +1,4 @@
-from ._version import version_info, __version__
-
+from ._version import __version__, version_info
 from .bandsplot import *
 
 
@@ -16,10 +15,12 @@ def _jupyter_labextension_paths():
         from `src` directory into <jupyter path>/labextensions/<dest> directory
         during widget installation
     """
-    return [{
-        'src': 'labextension',
-        'dest': 'widget-bandsplot',
-    }]
+    return [
+        {
+            "src": "labextension",
+            "dest": "widget-bandsplot",
+        }
+    ]
 
 
 def _jupyter_nbextension_paths():
@@ -39,9 +40,11 @@ def _jupyter_nbextension_paths():
     require: Path to importable AMD Javascript module inside the
         <jupyter path>/nbextensions/<dest> directory
     """
-    return [{
-        'section': 'notebook',
-        'src': 'nbextension',
-        'dest': 'widget-bandsplot',
-        'require': 'widget-bandsplot/extension'
-    }]
+    return [
+        {
+            "section": "notebook",
+            "src": "nbextension",
+            "dest": "widget-bandsplot",
+            "require": "widget-bandsplot/extension",
+        }
+    ]
